:py:mod:`timer_com`
===================

.. py:module:: timer_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Timer

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Signal Out']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Output']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'SignalOut', 'Delay Generator (sec)', 'a', 'b', 'c']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'str', 'list', 'float', 'float', 'float']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, 'True', ['constant: a=const', 'random uniform: a=min, b=max', 'random exponential:...

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: timer_com
   

   

